@@ -1,7 +1,9 @@
 # Copyright (c) 2015-2021 Patricio Cubillos and contributors.
-# MC3 is open-source software under the MIT license (see LICENSE).
+# mc3 is open-source software under the MIT license (see LICENSE).
 
-__all__ = ['fit']
+__all__ = [
+    'fit',
+    ]
 
 import numpy as np
 import scipy.optimize as so
